@@ -1,17 +1,15 @@
 package Pod::Weaver::Section::Completion::PerinciCmdLine;
 
-our $DATE = '2014-12-28'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-04-01'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use Moose;
+with 'Pod::Weaver::Role::AddTextToSection';
 with 'Pod::Weaver::Role::DetectPerinciCmdLineScript';
 with 'Pod::Weaver::Role::Section';
 with 'Pod::Weaver::Role::SectionText::SelfCompletion';
 
-use List::Util qw(first);
-use Moose::Autobox;
-
 sub weave_section {
     my ($self, $document, $input) = @_;
 
@@ -32,15 +30,7 @@ sub weave_section {
 
     my $text = $self->section_text({command_name=>$command_name});
 
-    $document->children->push(
-        Pod::Elemental::Element::Nested->new({
-            command  => 'head1',
-            content  => 'COMPLETION',
-            children => [
-                map { s/\n/ /g; Pod::Elemental::Element::Pod5::Ordinary->new({ content => $_ })} split /\n\n/, $text
-            ],
-        }),
-    );
+    $self->add_text_to_section($document, $text, 'COMPLETION');
 }
 
 no Moose;
@@ -59,7 +49,7 @@ Pod::Weaver::Section::Completion::PerinciCmdLine - Add a COMPLETION section for
 
 =head1 VERSION
 
-This document describes version 0.09 of Pod::Weaver::Section::Completion::PerinciCmdLine (from Perl distribution Pod-Weaver-Section-Completion-PerinciCmdLine), released on 2014-12-28.
+This document describes version 0.10 of Pod::Weaver::Section::Completion::PerinciCmdLine (from Perl distribution Pod-Weaver-Section-Completion-PerinciCmdLine), released on 2015-04-01.
 
 =head1 SYNOPSIS
 
@@ -94,14 +84,13 @@ Please report any bugs or feature requests on the bugtracker website L<https://r
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
